//
//  YHEducationDetailVC.swift
//  galaxy
//
//  Created by edy on 2024/2/7.
//  Copyright © 2024 https://www.galaxy-immi.com. All rights reserved.
//

import UIKit
import SwifterSwift
import Toast_Swift

class YHEducationDetailVC: YHBaseViewController {
    //【WARNING!】新添加 传orderId 已有信息传detailId
    // 订单ID
    var orderId: Int = 0
    // 学历ID
    var detailId: Int = 0
    let educationRequest:YHEducationRequestViewModel = YHEducationRequestViewModel()
    var detailInfo: YHEducationDetailInfo = YHEducationDetailInfo()
    var isChildsEditMode: YHFormTitleItemEditType = .none
    var isBrothersEditMode: YHFormTitleItemEditType = .none
    
    var items:[[YHFormItemProtocol]] = []
    
    lazy var tableView: UITableView = {
        
        let tableView = UITableView(frame:.zero, style:.plain)
        
        if #available(iOS 11.0, *) {
            tableView.contentInsetAdjustmentBehavior = .never
        }
        tableView.showsVerticalScrollIndicator = false
        tableView.backgroundColor = .clear
        tableView.separatorStyle = .none
        tableView.delegate = self
        tableView.dataSource = self
        tableView.register(UITableViewCell.self, forCellReuseIdentifier: "UITableViewCell")
        tableView.register(YHFormItemTitleCell.self, forCellReuseIdentifier: YHFormItemTitleCell.cellReuseIdentifier)
        tableView.register(YHFormItemAddCell.self, forCellReuseIdentifier: YHFormItemAddCell.cellReuseIdentifier)
        tableView.register(YHFormItemInputTextCell.self, forCellReuseIdentifier: YHFormItemInputTextCell.cellReuseIdentifier)
        tableView.register(YHFormItemSelectSheetCell.self, forCellReuseIdentifier: YHFormItemSelectSheetCell.cellReuseIdentifier)
        return tableView
    }()
    
    var bottomView: YHSaveAndSubmitView = {
        let view = YHSaveAndSubmitView.createView()
        return view
    }()
    
    override func viewDidLoad() {
        super.viewDidLoad()
        self.gk_navTitle = "学历".local
        view.backgroundColor = UIColor(hexString:"#F8F8F8")
        createUI()
    }
    
    override func viewWillAppear(_ animated: Bool) {
        super.viewWillAppear(animated)
    }
    
    func createUI() {
        
        view.addSubview(tableView);
        view.addSubview(bottomView)
        
        bottomView.saveBlock = {
            [weak self] in
            guard let self = self else { return }
            saveDetailInfo()
        }
        
        bottomView.snp.makeConstraints { make in
            make.left.right.equalToSuperview()
            make.bottom.equalToSuperview().offset(-k_Height_safeAreaInsetsBottom())
            make.height.equalTo(YHSaveAndSubmitView.height)
        }
        
        tableView.snp.makeConstraints { make in
            make.top.equalToSuperview().offset(k_Height_NavigationtBarAndStatuBar)
            make.bottom.equalTo(bottomView.snp.top)
            make.left.equalToSuperview().offset(16)
            make.right.equalToSuperview().offset(-16)
        }
        
        loadInfo()
        if self.detailId != 0 { // 有学历ID则该学历已存在
            getDetailInfo()
        } else { // 该学历是新添加的
            detailInfo.orderId = orderId
        }
    }
    
    func loadInfo() {
                
        items.removeAll()
        
        let title0 = YHFormTitleItem(type: .mainApplicantEducation)
        let item00 = YHFormDetailItem(type: .universityFullName)
        item00.placeHolder = "请输入学校全称，例：清华，需填全称“清华大学".local
        item00.value = detailInfo.college
        
        let item01 = YHFormDetailItem(type: .educationStyle)
        item01.placeHolder = "请选择授课形式".local
        item01.value = detailInfo.type
        
        let item02 = YHFormDetailItem(type: .educationTime)
        item02.placeHolder = "请选择年月".local
        item02.value = detailInfo.admissionTime
        
        
        let item03 = YHFormDetailItem(type: .graduateTime)
        item03.placeHolder = "请选择年月".local
        item03.value = detailInfo.graduateTime
        
        let item04 = YHFormDetailItem(type: .educationMajor)
        item04.placeHolder = "请输入专业".local
        item04.value = detailInfo.professional
        
        let item05 = YHFormDetailItem(type: .educationDegree)
        item05.placeHolder = "请选择学位".local
        item05.value = detailInfo.background
        
        let item06 = YHFormDetailItem(type: .degreeType)
        item06.placeHolder = "请输入学位类型，如管理学".local
        item06.value = detailInfo.degreeType

        let item07 = YHFormDetailItem(type: .educationCountry)
        item07.placeHolder = "请输入国家及地区".local
        item07.value = detailInfo.schoolAddress?.country
        
        let item08 = YHFormDetailItem(type: .educationCity)
        item08.placeHolder = "请选择城市".local

        if detailInfo.isSchoolInAboard() {
            item08.value = detailInfo.schoolAddress?.foreign
            item08.placeHolder = "请输入城市".local
            item08.tips = "请输入城市".local

        } else {
            item08.value = detailInfo.schoolAddress?.area.joined(separator: ",")
            item08.placeHolder = "请选择出生城市".local
            item08.tips = "请选择出生城市".local
        }
        
        let arr0:[YHFormItemProtocol] = [title0, item00, item01, item02, item03, item04, item05, item06, item07, item08]
        items.append(arr0)
        self.tableView.reloadData()
    }
}

extension YHEducationDetailVC : UITableViewDelegate, UITableViewDataSource {
    
    func numberOfSections(in tableView: UITableView) -> Int {
        return items.count
    }
    
    func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        if section >= items.count { return 0 }
        let arr = items[section]
        return arr.count
    }
    
    func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
        
        if indexPath.section >= items.count { return createDefaultCell(indexPath) }
        let arr:[YHFormItemProtocol] = items[indexPath.section]
        if indexPath.row >= arr.count {  return createDefaultCell(indexPath) }
        let item:YHFormItemProtocol = arr[indexPath.row]

        if item is YHFormTitleItem { // 是标题
            
            let formItem = item as! YHFormTitleItem
            let cell = tableView.dequeueReusableCell(withIdentifier: YHFormItemTitleCell.cellReuseIdentifier, for: indexPath) as! YHFormItemTitleCell
            cell.titleLabel.text = formItem.getTitle()
            cell.subTitleLabel.text = formItem.getSubTitle()
            return cell
        }
        
        if item is YHFormDetailItem {
            
            let detailItem = item as! YHFormDetailItem
            let cellType = getCellType(detailItem)
            if cellType == .inputText {
                let cell = tableView.dequeueReusableCell(withIdentifier: YHFormItemInputTextCell.cellReuseIdentifier, for: indexPath) as! YHFormItemInputTextCell
                cell.placeHolder = detailItem.placeHolder
                cell.isMust = detailItem.isNeed
                cell.title = detailItem.getTitle()
                cell.text = detailItem.value
                cell.textChange = {
                    [weak self] (text, isEditEnd) in
                    guard let self = self else { return }
                    // 只有国外城市才需输入，国内城市使用的是选择器
                    if detailItem.type == .educationCity {
                        if let text = text, !text.isEmpty {
                            detailInfo.schoolAddress?.foreign = text
                        } else {
                            detailInfo.schoolAddress?.foreign = ""
                        }
                        
                    } else if detailItem.type == .educationMajor {
                        detailInfo.professional = text
                    }
                    if isEditEnd {
                        loadInfo()
                        saveDetailInfo()
                    }
                }
                return cell
                
            } else if cellType == .selectSheet {
                let cell = tableView.dequeueReusableCell(withIdentifier: YHFormItemSelectSheetCell.cellReuseIdentifier, for: indexPath) as! YHFormItemSelectSheetCell
                cell.placeHolder = detailItem.placeHolder
                cell.isMust = detailItem.isNeed
                cell.title = detailItem.getTitle()
                cell.detail = detailItem.value
                return cell
            }
        }
        
        let cell = tableView.dequeueReusableCell(withIdentifier: "UITableViewCell", for: indexPath)
        return cell
    }
    
    func tableView(_ tableView: UITableView, willDisplay cell: UITableViewCell, forRowAt indexPath: IndexPath) {
        
        if indexPath.section >= items.count { return  }
        let arr:[YHFormItemProtocol] = items[indexPath.section]
        if indexPath.row >= arr.count {  return }
        
        createCorner(cell: cell, arr: arr, indexPath: indexPath)
    }
    
    func tableView(_ tableView: UITableView, heightForRowAt indexPath: IndexPath) -> CGFloat {
        
        let arr = items[indexPath.section]
        let item:YHFormItemProtocol = arr[indexPath.row]
        
        if item is YHFormTitleItem { // 是标题
            return 52.0
        }
        return UITableView.automaticDimension
    }
    
    func tableView(_ tableView: UITableView, viewForFooterInSection section: Int) -> UIView? {
        
        return UIView()
    }
    
    private func tableView(_ tableView: UITableView, viewForFooterInSection section: Int) -> CGFloat {
        return 14.0
    }
    
    func tableView(_ tableView: UITableView, didSelectRowAt indexPath: IndexPath) {
        
        let arr = items[indexPath.section]
        let item:YHFormItemProtocol = arr[indexPath.row]
        
        // 标题
        if item is YHFormTitleItem {
            return
        }
        if item is YHFormDetailItem {
            let detailItem = item as! YHFormDetailItem
            
            if detailItem.type == .universityFullName { // 选择大学名称
                
            } else if detailItem.type == .educationStyle { // 授课形式
                YHFormPickerView.show(type: .edution, selectType: .education(.fullTime)) {
                   [weak self] selectType in
                    guard let self = self else { return }
                    detailInfo.type = selectType.title
                    loadInfo()
                    saveDetailInfo()
                }
                
            } else if detailItem.type == .educationTime || detailItem.type == .graduateTime { // 入学及毕业年月
                
                YHDatePickView.show(type: .yyyymm) {
                    [weak self] date in
                    guard let self = self else { return }
                    if detailItem.type == .educationTime {
                        detailInfo.admissionTime = date
                        
                    } else if detailItem.type == .graduateTime {
                        detailInfo.graduateTime = date
                    }
                    loadInfo()
                    saveDetailInfo()
                }
                
            } else if detailItem.type == .educationDegree { // 学位
                
                YHFormPickerView.show(type: .degree, selectType: .degree(.bachelor)) {
                    [weak self] selectType in
                    guard let self = self else { return }
                    detailInfo.background = selectType.title
                    loadInfo()
                    saveDetailInfo()
                }
                
            } else if detailItem.type == .degreeType { // 学位类型
                
            } else if detailItem.type == .educationCountry { // 上课国家/地区
                
                let vc = YHSelectCountryViewController()
                 vc.backLocationStringController = {
                     [weak self] country in
                     guard let self = self else { return }
                     detailInfo.schoolAddress?.country = country
                     loadInfo()
                     saveDetailInfo()
                 }
                 self.navigationController?.pushViewController(vc)
                
            } else if detailItem.type == .educationCity { // 上课城市
                
                if detailInfo.isSchoolInAboard() { return }
                
                let vc = YHAddressViewController()
                vc.backLocationStringController = {
                     [weak self] (string1, string2, string3, string4) in
                     guard let self = self else { return }
                     detailInfo.schoolAddress?.area = [string1, string2, string3, string4]
                     loadInfo()
                     saveDetailInfo()
                 }
                self.present(vc, animated: true)
            }
        }
         
    }
    
    func createDefaultCell(_ indexPath: IndexPath) -> UITableViewCell {
        let cell = tableView.dequeueReusableCell(withIdentifier: "UITableViewCell", for: indexPath)
        return cell
    }
        
    func createCorner(cell:UITableViewCell, arr:Array<Any>, indexPath:IndexPath) {
        // 设置每块section圆角
        if (indexPath.row == 0) {
            let corner = UIRectCorner(rawValue: UIRectCorner.topLeft.rawValue | UIRectCorner.topRight.rawValue)
            cell.createCorner(CGSizeMake(12.0, 12.0), corner)
            
        } else if (indexPath.row == arr.count-1) {
            let corner = UIRectCorner(rawValue: UIRectCorner.bottomLeft.rawValue | UIRectCorner.bottomRight.rawValue)
            cell.createCorner(CGSizeMake(12.0, 12.0), corner)
            
        } else {
            cell.layer.mask = nil
        }
    }
    
    func getCellType(_ item: Any) ->HKFormItemCellType {
        if item is YHFormTitleItem {
            return .title
        }
        
        if item is YHFormDetailItem {
            let detailItem = item as! YHFormDetailItem
            
            if detailItem.type == .educationCity {
                if detailInfo.isSchoolInAboard() {
                    return .inputText
                }
                return .selectSheet
            }
            
            if  detailItem.type == .educationMajor
            {
                return .inputText
            }
            if detailItem.type == .universityFullName
                || detailItem.type == .educationStyle
                || detailItem.type == .educationTime
                || detailItem.type == .graduateTime
                || detailItem.type == .educationDegree
                || detailItem.type == .degreeType
                || detailItem.type == .educationCountry
            {
                
                return .selectSheet
            }
        }
        return .defaultType
    }
}

extension YHEducationDetailVC {
    func getDetailInfo() {
        self.educationRequest.getEducationDetailInfo(params: ["id": self.detailId]) {
            [weak self] success, error in
            guard let self = self else { return }
            if success {
                if let educationDetailInfo = self.educationRequest.educationDetailInfo {
                    detailInfo = educationDetailInfo
                }
                loadInfo()
            }
        }
    }
    
    func saveDetailInfo() {
        
        // detailInfo.toDictionary() 对于值为空的字段不会添加 而后台需要 所以如下处理
        let  dict:[String : Any] = ["verify": 0,
                                    "id": detailInfo.id,
                                    "order_id": detailInfo.orderId,
                                    "admission_time": detailInfo.admissionTime ?? "",
                                    "background": detailInfo.background ?? "",
                                    "college": detailInfo.college ?? "",
                                    "degree_type": detailInfo.degreeType ?? "",
                                    "graduate_time": detailInfo.graduateTime ?? "",
                                    "professional": detailInfo.professional ?? "",
                                    "school_address_aboard": "",
                                    "type": detailInfo.type ?? "",
                                    "school_address": ["country": detailInfo.schoolAddress?.country ?? "",
                                                       "area": detailInfo.schoolAddress?.area ?? "",
                                                       "foreign": detailInfo.schoolAddress?.foreign ?? ""],
                                    ]
    
        self.educationRequest.saveEducationInfo(params: dict) {
            [weak self] success, error in
            guard let self = self else { return }
            if success {
                self.view.makeToast("保存成功", duration: 1.0, position:ToastPosition.center)
                
            } else {
                self.view.makeToast("保存失败", duration: 1.0, position:ToastPosition.center)
            }
            DispatchQueue.main.asyncAfter(deadline:.now()+1.0) {
                self.view.hideToast()
            }
        }
    }
}
